# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_REGISTRATION_SY_NQUICK_SH_METADATA = Metadata(
    id="95f42ebdf9e80a10a0b738811253de777466a830.boutiques",
    name="antsRegistrationSyNQuick.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsRegistrationSyNquickShParameters = typing.TypedDict('AntsRegistrationSyNquickShParameters', {
    "__STYX_TYPE__": typing.Literal["antsRegistrationSyNQuick.sh"],
    "dimensionality": typing.Literal[2, 3],
    "fixed_image": InputPathType,
    "moving_image": InputPathType,
    "output_prefix": str,
    "transform_type": typing.NotRequired[typing.Literal["s", "b"] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsRegistrationSyNQuick.sh": ants_registration_sy_nquick_sh_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsRegistrationSyNQuick.sh": ants_registration_sy_nquick_sh_outputs,
    }.get(t)


class AntsRegistrationSyNquickShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_registration_sy_nquick_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform: OutputPathType
    """Affine transformation matrix resulting from registration."""
    output_warp: OutputPathType
    """Warp field resulting from the registration."""
    output_inverse_warp: OutputPathType
    """Inverse warp field resulting from the registration."""
    output_warped_image: OutputPathType
    """Warped moving image."""


def ants_registration_sy_nquick_sh_params(
    dimensionality: typing.Literal[2, 3],
    fixed_image: InputPathType,
    moving_image: InputPathType,
    output_prefix: str,
    transform_type: typing.Literal["s", "b"] | None = None,
) -> AntsRegistrationSyNquickShParameters:
    """
    Build parameters.
    
    Args:
        dimensionality: Dimensionality of the images (2 or 3).
        fixed_image: Fixed image to which the moving image is registered.
        moving_image: Moving image that is registered to the fixed image.
        output_prefix: Prefix for the output files.
        transform_type: Type of transform: 's' for SyN, 'b' for B-spline SyN.\
            Default is 's'.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsRegistrationSyNQuick.sh",
        "dimensionality": dimensionality,
        "fixed_image": fixed_image,
        "moving_image": moving_image,
        "output_prefix": output_prefix,
    }
    if transform_type is not None:
        params["transform_type"] = transform_type
    return params


def ants_registration_sy_nquick_sh_cargs(
    params: AntsRegistrationSyNquickShParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsRegistrationSyNQuick.sh")
    cargs.extend([
        "-d",
        str(params.get("dimensionality"))
    ])
    cargs.extend([
        "-f",
        execution.input_file(params.get("fixed_image"))
    ])
    cargs.extend([
        "-m",
        execution.input_file(params.get("moving_image"))
    ])
    cargs.extend([
        "-o",
        params.get("output_prefix")
    ])
    if params.get("transform_type") is not None:
        cargs.append(params.get("transform_type"))
    return cargs


def ants_registration_sy_nquick_sh_outputs(
    params: AntsRegistrationSyNquickShParameters,
    execution: Execution,
) -> AntsRegistrationSyNquickShOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsRegistrationSyNquickShOutputs(
        root=execution.output_file("."),
        output_transform=execution.output_file(params.get("output_prefix") + "0GenericAffine.mat"),
        output_warp=execution.output_file(params.get("output_prefix") + "1Warp.nii.gz"),
        output_inverse_warp=execution.output_file(params.get("output_prefix") + "1InverseWarp.nii.gz"),
        output_warped_image=execution.output_file(params.get("output_prefix") + "Warped.nii.gz"),
    )
    return ret


def ants_registration_sy_nquick_sh_execute(
    params: AntsRegistrationSyNquickShParameters,
    execution: Execution,
) -> AntsRegistrationSyNquickShOutputs:
    """
    A script to quickly compute a SyN-based registration between two images using
    ANTS.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsRegistrationSyNquickShOutputs`).
    """
    params = execution.params(params)
    cargs = ants_registration_sy_nquick_sh_cargs(params, execution)
    ret = ants_registration_sy_nquick_sh_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_registration_sy_nquick_sh(
    dimensionality: typing.Literal[2, 3],
    fixed_image: InputPathType,
    moving_image: InputPathType,
    output_prefix: str,
    transform_type: typing.Literal["s", "b"] | None = None,
    runner: Runner | None = None,
) -> AntsRegistrationSyNquickShOutputs:
    """
    A script to quickly compute a SyN-based registration between two images using
    ANTS.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimensionality: Dimensionality of the images (2 or 3).
        fixed_image: Fixed image to which the moving image is registered.
        moving_image: Moving image that is registered to the fixed image.
        output_prefix: Prefix for the output files.
        transform_type: Type of transform: 's' for SyN, 'b' for B-spline SyN.\
            Default is 's'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsRegistrationSyNquickShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_REGISTRATION_SY_NQUICK_SH_METADATA)
    params = ants_registration_sy_nquick_sh_params(
        dimensionality=dimensionality,
        fixed_image=fixed_image,
        moving_image=moving_image,
        output_prefix=output_prefix,
        transform_type=transform_type,
    )
    return ants_registration_sy_nquick_sh_execute(params, execution)


__all__ = [
    "ANTS_REGISTRATION_SY_NQUICK_SH_METADATA",
    "AntsRegistrationSyNquickShOutputs",
    "AntsRegistrationSyNquickShParameters",
    "ants_registration_sy_nquick_sh",
    "ants_registration_sy_nquick_sh_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

I_MATH_METADATA = Metadata(
    id="82da58a8a784459b76c3083f4eca6f26d139e8c9.boutiques",
    name="iMath",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


IMathParameters = typing.TypedDict('IMathParameters', {
    "__STYX_TYPE__": typing.Literal["iMath"],
    "image_dimension": typing.Literal[2, 3, 4],
    "output_image": str,
    "operations": str,
    "image1": InputPathType,
    "image2": typing.NotRequired[InputPathType | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "iMath": i_math_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "iMath": i_math_outputs,
    }.get(t)


class IMathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `i_math(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resulting_image: OutputPathType
    """The output image resulting from the operation."""


def i_math_params(
    image_dimension: typing.Literal[2, 3, 4],
    output_image: str,
    operations: str,
    image1: InputPathType,
    image2: InputPathType | None = None,
) -> IMathParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Dimensionality of the image, either 2, 3, or 4.
        output_image: Path for the output image file.
        operations: Operations to be performed along with parameters, e.g.,\
            GetLargestComponent, MC for Closing, etc.
        image1: First input image file.
        image2: Second input image file, if required by operation.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "iMath",
        "image_dimension": image_dimension,
        "output_image": output_image,
        "operations": operations,
        "image1": image1,
    }
    if image2 is not None:
        params["image2"] = image2
    return params


def i_math_cargs(
    params: IMathParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("iMath")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(params.get("output_image"))
    cargs.append(params.get("operations"))
    cargs.append(execution.input_file(params.get("image1")))
    if params.get("image2") is not None:
        cargs.append(execution.input_file(params.get("image2")))
    return cargs


def i_math_outputs(
    params: IMathParameters,
    execution: Execution,
) -> IMathOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = IMathOutputs(
        root=execution.output_file("."),
        resulting_image=execution.output_file(params.get("output_image")),
    )
    return ret


def i_math_execute(
    params: IMathParameters,
    execution: Execution,
) -> IMathOutputs:
    """
    iMath is a tool for performing various image mathematical operations on medical
    images, specifically supporting operations on 2D, 3D, and 4D data.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `IMathOutputs`).
    """
    params = execution.params(params)
    cargs = i_math_cargs(params, execution)
    ret = i_math_outputs(params, execution)
    execution.run(cargs)
    return ret


def i_math(
    image_dimension: typing.Literal[2, 3, 4],
    output_image: str,
    operations: str,
    image1: InputPathType,
    image2: InputPathType | None = None,
    runner: Runner | None = None,
) -> IMathOutputs:
    """
    iMath is a tool for performing various image mathematical operations on medical
    images, specifically supporting operations on 2D, 3D, and 4D data.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the image, either 2, 3, or 4.
        output_image: Path for the output image file.
        operations: Operations to be performed along with parameters, e.g.,\
            GetLargestComponent, MC for Closing, etc.
        image1: First input image file.
        image2: Second input image file, if required by operation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IMathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(I_MATH_METADATA)
    params = i_math_params(
        image_dimension=image_dimension,
        output_image=output_image,
        operations=operations,
        image1=image1,
        image2=image2,
    )
    return i_math_execute(params, execution)


__all__ = [
    "IMathOutputs",
    "IMathParameters",
    "I_MATH_METADATA",
    "i_math",
    "i_math_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

MULTIPLY_IMAGES_METADATA = Metadata(
    id="3421bb6ea5f44c4d4eb0d2dd002f4de6f489cf86.boutiques",
    name="MultiplyImages",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


MultiplyImagesParameters = typing.TypedDict('MultiplyImagesParameters', {
    "__STYX_TYPE__": typing.Literal["MultiplyImages"],
    "dimension": typing.Literal[3, 2],
    "first_input": InputPathType,
    "second_input_2": typing.NotRequired[float | None],
    "output_product_image": str,
    "num_threads": typing.NotRequired[int | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "MultiplyImages": multiply_images_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "MultiplyImages": multiply_images_outputs,
    }.get(t)


class MultiplyImagesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `multiply_images(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_product_image_outfile: OutputPathType
    """Average image file."""


def multiply_images_params(
    dimension: typing.Literal[3, 2],
    first_input: InputPathType,
    output_product_image: str,
    second_input_2: float | None = None,
    num_threads: int | None = 1,
) -> MultiplyImagesParameters:
    """
    Build parameters.
    
    Args:
        dimension: 3 or 2. Image dimension (2 or 3).
        first_input: Image 1.
        output_product_image: Outputfname.nii.gz: the name of the resulting\
            image.
        second_input_2: file or string or a float. Image 2 or multiplication\
            weight.
        num_threads: Number of itk threads to use.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "MultiplyImages",
        "dimension": dimension,
        "first_input": first_input,
        "output_product_image": output_product_image,
    }
    if second_input_2 is not None:
        params["second_input_2"] = second_input_2
    if num_threads is not None:
        params["num_threads"] = num_threads
    return params


def multiply_images_cargs(
    params: MultiplyImagesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("MultiplyImages")
    cargs.append(str(params.get("dimension")))
    cargs.append(execution.input_file(params.get("first_input")))
    if params.get("second_input_2") is not None:
        cargs.append(str(params.get("second_input_2")))
    cargs.append(params.get("output_product_image"))
    if params.get("num_threads") is not None:
        cargs.append(str(params.get("num_threads")))
    return cargs


def multiply_images_outputs(
    params: MultiplyImagesParameters,
    execution: Execution,
) -> MultiplyImagesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MultiplyImagesOutputs(
        root=execution.output_file("."),
        output_product_image_outfile=execution.output_file(params.get("output_product_image")),
    )
    return ret


def multiply_images_execute(
    params: MultiplyImagesParameters,
    execution: Execution,
) -> MultiplyImagesOutputs:
    """
    Multiply 2 images; 2nd image file may also be floating point numerical value,
    and program will act accordingly -- i.e. read as a number. Program handles
    vector and tensor images as well.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `MultiplyImagesOutputs`).
    """
    params = execution.params(params)
    cargs = multiply_images_cargs(params, execution)
    ret = multiply_images_outputs(params, execution)
    execution.run(cargs)
    return ret


def multiply_images(
    dimension: typing.Literal[3, 2],
    first_input: InputPathType,
    output_product_image: str,
    second_input_2: float | None = None,
    num_threads: int | None = 1,
    runner: Runner | None = None,
) -> MultiplyImagesOutputs:
    """
    Multiply 2 images; 2nd image file may also be floating point numerical value,
    and program will act accordingly -- i.e. read as a number. Program handles
    vector and tensor images as well.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: 3 or 2. Image dimension (2 or 3).
        first_input: Image 1.
        output_product_image: Outputfname.nii.gz: the name of the resulting\
            image.
        second_input_2: file or string or a float. Image 2 or multiplication\
            weight.
        num_threads: Number of itk threads to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MultiplyImagesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MULTIPLY_IMAGES_METADATA)
    params = multiply_images_params(
        dimension=dimension,
        first_input=first_input,
        second_input_2=second_input_2,
        output_product_image=output_product_image,
        num_threads=num_threads,
    )
    return multiply_images_execute(params, execution)


__all__ = [
    "MULTIPLY_IMAGES_METADATA",
    "MultiplyImagesOutputs",
    "MultiplyImagesParameters",
    "multiply_images",
    "multiply_images_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CONVERT_TO_JPG_METADATA = Metadata(
    id="5bc8a9ac227d992d762dc5365725a949c90f5c17.boutiques",
    name="ConvertToJpg",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


ConvertToJpgParameters = typing.TypedDict('ConvertToJpgParameters', {
    "__STYX_TYPE__": typing.Literal["ConvertToJpg"],
    "infile": InputPathType,
    "outfile": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "ConvertToJpg": convert_to_jpg_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "ConvertToJpg": convert_to_jpg_outputs,
    }.get(t)


class ConvertToJpgOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_to_jpg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jpg: OutputPathType
    """The converted JPG image."""


def convert_to_jpg_params(
    infile: InputPathType,
    outfile: str,
) -> ConvertToJpgParameters:
    """
    Build parameters.
    
    Args:
        infile: The input file in NIfTI format.
        outfile: The output file in JPG format.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "ConvertToJpg",
        "infile": infile,
        "outfile": outfile,
    }
    return params


def convert_to_jpg_cargs(
    params: ConvertToJpgParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("ConvertToJpg" + execution.input_file(params.get("infile")) + params.get("outfile"))
    return cargs


def convert_to_jpg_outputs(
    params: ConvertToJpgParameters,
    execution: Execution,
) -> ConvertToJpgOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertToJpgOutputs(
        root=execution.output_file("."),
        output_jpg=execution.output_file(params.get("outfile")),
    )
    return ret


def convert_to_jpg_execute(
    params: ConvertToJpgParameters,
    execution: Execution,
) -> ConvertToJpgOutputs:
    """
    A tool to convert NIfTI images to JPG format.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `ConvertToJpgOutputs`).
    """
    params = execution.params(params)
    cargs = convert_to_jpg_cargs(params, execution)
    ret = convert_to_jpg_outputs(params, execution)
    execution.run(cargs)
    return ret


def convert_to_jpg(
    infile: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> ConvertToJpgOutputs:
    """
    A tool to convert NIfTI images to JPG format.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        infile: The input file in NIfTI format.
        outfile: The output file in JPG format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertToJpgOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_TO_JPG_METADATA)
    params = convert_to_jpg_params(
        infile=infile,
        outfile=outfile,
    )
    return convert_to_jpg_execute(params, execution)


__all__ = [
    "CONVERT_TO_JPG_METADATA",
    "ConvertToJpgOutputs",
    "ConvertToJpgParameters",
    "convert_to_jpg",
    "convert_to_jpg_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_CORTICAL_THICKNESS_SH_METADATA = Metadata(
    id="927ff3d34dcb64b2fcbc355449b1223268e7ab32.boutiques",
    name="antsCorticalThickness.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsCorticalThicknessShParameters = typing.TypedDict('AntsCorticalThicknessShParameters', {
    "__STYX_TYPE__": typing.Literal["antsCorticalThickness.sh"],
    "image_dimension": typing.Literal[2, 3],
    "anatomical_image": InputPathType,
    "brain_template": InputPathType,
    "brain_extraction_probability_mask": InputPathType,
    "brain_segmentation_priors": str,
    "output_prefix": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsCorticalThickness.sh": ants_cortical_thickness_sh_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsCorticalThickness.sh": ants_cortical_thickness_sh_outputs,
    }.get(t)


class AntsCorticalThicknessShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_cortical_thickness_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cortical_thickness: OutputPathType
    """The output cortical thickness map."""
    brain_extraction_mask: OutputPathType
    """The brain extraction mask."""
    brain_segmentation: OutputPathType
    """The brain segmentation image."""
    segmentation_posteriors: OutputPathType
    """The segmentation posteriors for different tissue classes."""


def ants_cortical_thickness_sh_params(
    image_dimension: typing.Literal[2, 3],
    anatomical_image: InputPathType,
    brain_template: InputPathType,
    brain_extraction_probability_mask: InputPathType,
    brain_segmentation_priors: str,
    output_prefix: str,
) -> AntsCorticalThicknessShParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: 2 or 3 for 2- or 3-dimensional image.
        anatomical_image: Structural intensity image, typically T1.
        brain_template: Anatomical intensity template. This template is not\
            skull-stripped.
        brain_extraction_probability_mask: Brain probability mask in the\
            segmentation template space. A binary mask is acceptable.
        brain_segmentation_priors: Tissue probability priors corresponding to\
            the template image specified with the -e option. At least four priors\
            must exist, corresponding to CSF, Cortical GM, WM, Subcortical GM.
        output_prefix: Output prefix for the generated filenames.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsCorticalThickness.sh",
        "image_dimension": image_dimension,
        "anatomical_image": anatomical_image,
        "brain_template": brain_template,
        "brain_extraction_probability_mask": brain_extraction_probability_mask,
        "brain_segmentation_priors": brain_segmentation_priors,
        "output_prefix": output_prefix,
    }
    return params


def ants_cortical_thickness_sh_cargs(
    params: AntsCorticalThicknessShParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsCorticalThickness.sh")
    cargs.extend([
        "-d",
        str(params.get("image_dimension"))
    ])
    cargs.extend([
        "-a",
        execution.input_file(params.get("anatomical_image"))
    ])
    cargs.extend([
        "-e",
        execution.input_file(params.get("brain_template"))
    ])
    cargs.extend([
        "-m",
        execution.input_file(params.get("brain_extraction_probability_mask"))
    ])
    cargs.extend([
        "-p",
        params.get("brain_segmentation_priors")
    ])
    cargs.append("[ADDITIONAL_PARAMETERS]")
    cargs.extend([
        "-o",
        params.get("output_prefix")
    ])
    return cargs


def ants_cortical_thickness_sh_outputs(
    params: AntsCorticalThicknessShParameters,
    execution: Execution,
) -> AntsCorticalThicknessShOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsCorticalThicknessShOutputs(
        root=execution.output_file("."),
        cortical_thickness=execution.output_file(params.get("output_prefix") + "CorticalThickness.nii.gz"),
        brain_extraction_mask=execution.output_file(params.get("output_prefix") + "BrainExtractionMask.nii.gz"),
        brain_segmentation=execution.output_file(params.get("output_prefix") + "BrainSegmentation.nii.gz"),
        segmentation_posteriors=execution.output_file(params.get("output_prefix") + "BrainSegmentationPosteriors*.nii.gz"),
    )
    return ret


def ants_cortical_thickness_sh_execute(
    params: AntsCorticalThicknessShParameters,
    execution: Execution,
) -> AntsCorticalThicknessShOutputs:
    """
    This script performs T1 anatomical brain processing including brain extraction,
    brain n-tissue segmentation, cortical thickness estimation, and optional
    registration to a template.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsCorticalThicknessShOutputs`).
    """
    params = execution.params(params)
    cargs = ants_cortical_thickness_sh_cargs(params, execution)
    ret = ants_cortical_thickness_sh_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_cortical_thickness_sh(
    image_dimension: typing.Literal[2, 3],
    anatomical_image: InputPathType,
    brain_template: InputPathType,
    brain_extraction_probability_mask: InputPathType,
    brain_segmentation_priors: str,
    output_prefix: str,
    runner: Runner | None = None,
) -> AntsCorticalThicknessShOutputs:
    """
    This script performs T1 anatomical brain processing including brain extraction,
    brain n-tissue segmentation, cortical thickness estimation, and optional
    registration to a template.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: 2 or 3 for 2- or 3-dimensional image.
        anatomical_image: Structural intensity image, typically T1.
        brain_template: Anatomical intensity template. This template is not\
            skull-stripped.
        brain_extraction_probability_mask: Brain probability mask in the\
            segmentation template space. A binary mask is acceptable.
        brain_segmentation_priors: Tissue probability priors corresponding to\
            the template image specified with the -e option. At least four priors\
            must exist, corresponding to CSF, Cortical GM, WM, Subcortical GM.
        output_prefix: Output prefix for the generated filenames.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsCorticalThicknessShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_CORTICAL_THICKNESS_SH_METADATA)
    params = ants_cortical_thickness_sh_params(
        image_dimension=image_dimension,
        anatomical_image=anatomical_image,
        brain_template=brain_template,
        brain_extraction_probability_mask=brain_extraction_probability_mask,
        brain_segmentation_priors=brain_segmentation_priors,
        output_prefix=output_prefix,
    )
    return ants_cortical_thickness_sh_execute(params, execution)


__all__ = [
    "ANTS_CORTICAL_THICKNESS_SH_METADATA",
    "AntsCorticalThicknessShOutputs",
    "AntsCorticalThicknessShParameters",
    "ants_cortical_thickness_sh",
    "ants_cortical_thickness_sh_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_INTERMODALITY_INTRASUBJECT_SH_METADATA = Metadata(
    id="e4f43efff74611f07e60c00f682c377a411a79c7.boutiques",
    name="antsIntermodalityIntrasubject.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsIntermodalityIntrasubjectShParameters = typing.TypedDict('AntsIntermodalityIntrasubjectShParameters', {
    "__STYX_TYPE__": typing.Literal["antsIntermodalityIntrasubject.sh"],
    "dimension": int,
    "anatomical_t1_image": InputPathType,
    "anatomical_reference_image": typing.NotRequired[InputPathType | None],
    "scalar_image_to_match": InputPathType,
    "anatomical_t1brainmask": InputPathType,
    "transform_type": typing.Literal[0, 1, 2, 3],
    "t1_to_template_prefix": str,
    "template_space": typing.NotRequired[str | None],
    "output_prefix": str,
    "labels_in_template_space": typing.NotRequired[InputPathType | None],
    "auxiliary_scalar_images": typing.NotRequired[InputPathType | None],
    "auxiliary_dt_image": typing.NotRequired[InputPathType | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsIntermodalityIntrasubject.sh": ants_intermodality_intrasubject_sh_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsIntermodalityIntrasubject.sh": ants_intermodality_intrasubject_sh_outputs,
    }.get(t)


class AntsIntermodalityIntrasubjectShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_intermodality_intrasubject_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transformed_image: OutputPathType
    """Output transformed image after registration."""
    output_transform: OutputPathType
    """Transformation matrix or warp field from the registration."""
    output_warped_image: OutputPathType
    """Output warped image in the template space."""


def ants_intermodality_intrasubject_sh_params(
    dimension: int,
    anatomical_t1_image: InputPathType,
    scalar_image_to_match: InputPathType,
    anatomical_t1brainmask: InputPathType,
    transform_type: typing.Literal[0, 1, 2, 3],
    t1_to_template_prefix: str,
    output_prefix: str,
    anatomical_reference_image: InputPathType | None = None,
    template_space: str | None = None,
    labels_in_template_space: InputPathType | None = None,
    auxiliary_scalar_images: InputPathType | None = None,
    auxiliary_dt_image: InputPathType | None = None,
) -> AntsIntermodalityIntrasubjectShParameters:
    """
    Build parameters.
    
    Args:
        dimension: Dimensionality of the image, typically 3 for 3D images.
        anatomical_t1_image: Anatomical T1 image (brain or whole-head) to align\
            to.
        scalar_image_to_match: Scalar image to be matched, such as average\
            BOLD, average DWI, etc.
        anatomical_t1brainmask: Brain mask for the anatomical T1 image, should\
            mask out regions not appearing in the scalar image.
        transform_type: Type of transform: 0=rigid, 1=affine,\
            2=rigid+small_def, 3=affine+small_def.
        t1_to_template_prefix: Prefix for T1 to template transform files.
        output_prefix: Prefix for output files.
        anatomical_reference_image: Anatomical reference image to warp to,\
            often higher resolution than the anatomical T1 image.
        template_space: Template space.
        labels_in_template_space: Labels in the template space.
        auxiliary_scalar_images: Auxiliary scalar images to warp to the\
            template.
        auxiliary_dt_image: Auxiliary DT image to warp to the template.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsIntermodalityIntrasubject.sh",
        "dimension": dimension,
        "anatomical_t1_image": anatomical_t1_image,
        "scalar_image_to_match": scalar_image_to_match,
        "anatomical_t1brainmask": anatomical_t1brainmask,
        "transform_type": transform_type,
        "t1_to_template_prefix": t1_to_template_prefix,
        "output_prefix": output_prefix,
    }
    if anatomical_reference_image is not None:
        params["anatomical_reference_image"] = anatomical_reference_image
    if template_space is not None:
        params["template_space"] = template_space
    if labels_in_template_space is not None:
        params["labels_in_template_space"] = labels_in_template_space
    if auxiliary_scalar_images is not None:
        params["auxiliary_scalar_images"] = auxiliary_scalar_images
    if auxiliary_dt_image is not None:
        params["auxiliary_dt_image"] = auxiliary_dt_image
    return params


def ants_intermodality_intrasubject_sh_cargs(
    params: AntsIntermodalityIntrasubjectShParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsIntermodalityIntrasubject.sh")
    cargs.extend([
        "-d",
        str(params.get("dimension"))
    ])
    cargs.extend([
        "-r",
        execution.input_file(params.get("anatomical_t1_image"))
    ])
    if params.get("anatomical_reference_image") is not None:
        cargs.extend([
            "-R",
            execution.input_file(params.get("anatomical_reference_image"))
        ])
    cargs.extend([
        "-i",
        execution.input_file(params.get("scalar_image_to_match"))
    ])
    cargs.extend([
        "-x",
        execution.input_file(params.get("anatomical_t1brainmask"))
    ])
    cargs.extend([
        "-t",
        str(params.get("transform_type"))
    ])
    cargs.extend([
        "-w",
        params.get("t1_to_template_prefix")
    ])
    if params.get("template_space") is not None:
        cargs.extend([
            "-T",
            params.get("template_space")
        ])
    cargs.extend([
        "-o",
        params.get("output_prefix")
    ])
    if params.get("labels_in_template_space") is not None:
        cargs.extend([
            "-l",
            execution.input_file(params.get("labels_in_template_space"))
        ])
    if params.get("auxiliary_scalar_images") is not None:
        cargs.extend([
            "-a",
            execution.input_file(params.get("auxiliary_scalar_images"))
        ])
    if params.get("auxiliary_dt_image") is not None:
        cargs.extend([
            "-b",
            execution.input_file(params.get("auxiliary_dt_image"))
        ])
    return cargs


def ants_intermodality_intrasubject_sh_outputs(
    params: AntsIntermodalityIntrasubjectShParameters,
    execution: Execution,
) -> AntsIntermodalityIntrasubjectShOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsIntermodalityIntrasubjectShOutputs(
        root=execution.output_file("."),
        output_transformed_image=execution.output_file(params.get("output_prefix") + "Transformed.nii.gz"),
        output_transform=execution.output_file(params.get("output_prefix") + "Transform.mat"),
        output_warped_image=execution.output_file(params.get("output_prefix") + "Warped.nii.gz"),
    )
    return ret


def ants_intermodality_intrasubject_sh_execute(
    params: AntsIntermodalityIntrasubjectShParameters,
    execution: Execution,
) -> AntsIntermodalityIntrasubjectShOutputs:
    """
    Performs registration between a scalar image and a T1 image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsIntermodalityIntrasubjectShOutputs`).
    """
    params = execution.params(params)
    cargs = ants_intermodality_intrasubject_sh_cargs(params, execution)
    ret = ants_intermodality_intrasubject_sh_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_intermodality_intrasubject_sh(
    dimension: int,
    anatomical_t1_image: InputPathType,
    scalar_image_to_match: InputPathType,
    anatomical_t1brainmask: InputPathType,
    transform_type: typing.Literal[0, 1, 2, 3],
    t1_to_template_prefix: str,
    output_prefix: str,
    anatomical_reference_image: InputPathType | None = None,
    template_space: str | None = None,
    labels_in_template_space: InputPathType | None = None,
    auxiliary_scalar_images: InputPathType | None = None,
    auxiliary_dt_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> AntsIntermodalityIntrasubjectShOutputs:
    """
    Performs registration between a scalar image and a T1 image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: Dimensionality of the image, typically 3 for 3D images.
        anatomical_t1_image: Anatomical T1 image (brain or whole-head) to align\
            to.
        scalar_image_to_match: Scalar image to be matched, such as average\
            BOLD, average DWI, etc.
        anatomical_t1brainmask: Brain mask for the anatomical T1 image, should\
            mask out regions not appearing in the scalar image.
        transform_type: Type of transform: 0=rigid, 1=affine,\
            2=rigid+small_def, 3=affine+small_def.
        t1_to_template_prefix: Prefix for T1 to template transform files.
        output_prefix: Prefix for output files.
        anatomical_reference_image: Anatomical reference image to warp to,\
            often higher resolution than the anatomical T1 image.
        template_space: Template space.
        labels_in_template_space: Labels in the template space.
        auxiliary_scalar_images: Auxiliary scalar images to warp to the\
            template.
        auxiliary_dt_image: Auxiliary DT image to warp to the template.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsIntermodalityIntrasubjectShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_INTERMODALITY_INTRASUBJECT_SH_METADATA)
    params = ants_intermodality_intrasubject_sh_params(
        dimension=dimension,
        anatomical_t1_image=anatomical_t1_image,
        anatomical_reference_image=anatomical_reference_image,
        scalar_image_to_match=scalar_image_to_match,
        anatomical_t1brainmask=anatomical_t1brainmask,
        transform_type=transform_type,
        t1_to_template_prefix=t1_to_template_prefix,
        template_space=template_space,
        output_prefix=output_prefix,
        labels_in_template_space=labels_in_template_space,
        auxiliary_scalar_images=auxiliary_scalar_images,
        auxiliary_dt_image=auxiliary_dt_image,
    )
    return ants_intermodality_intrasubject_sh_execute(params, execution)


__all__ = [
    "ANTS_INTERMODALITY_INTRASUBJECT_SH_METADATA",
    "AntsIntermodalityIntrasubjectShOutputs",
    "AntsIntermodalityIntrasubjectShParameters",
    "ants_intermodality_intrasubject_sh",
    "ants_intermodality_intrasubject_sh_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

NON_LOCAL_SUPER_RESOLUTION_METADATA = Metadata(
    id="51aada9b4dbce0b9d25369841901cb709639d1e3.boutiques",
    name="NonLocalSuperResolution",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


NonLocalSuperResolutionParameters = typing.TypedDict('NonLocalSuperResolutionParameters', {
    "__STYX_TYPE__": typing.Literal["NonLocalSuperResolution"],
    "image_dimensionality": typing.NotRequired[typing.Literal[2, 3, 4] | None],
    "input_image": InputPathType,
    "interpolated_image": typing.NotRequired[InputPathType | None],
    "reference_image": typing.NotRequired[InputPathType | None],
    "patch_radius": typing.NotRequired[typing.Literal["1", "1x1x1"] | None],
    "search_radius": typing.NotRequired[typing.Literal["3", "3x3x3"] | None],
    "intensity_difference_sigma": typing.NotRequired[float | None],
    "patch_similarity_sigma": typing.NotRequired[float | None],
    "scale_levels": typing.NotRequired[str | None],
    "interpolation": typing.NotRequired[typing.Literal["Linear", "NearestNeighbor", "Gaussian", "BSpline", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None],
    "output": str,
    "verbose": typing.NotRequired[typing.Literal[0, 1] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "NonLocalSuperResolution": non_local_super_resolution_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "NonLocalSuperResolution": non_local_super_resolution_outputs,
    }.get(t)


class NonLocalSuperResolutionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `non_local_super_resolution(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    superresoluted_output: OutputPathType
    """The superresoluted output image."""


def non_local_super_resolution_params(
    input_image: InputPathType,
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    interpolated_image: InputPathType | None = None,
    reference_image: InputPathType | None = None,
    patch_radius: typing.Literal["1", "1x1x1"] | None = None,
    search_radius: typing.Literal["3", "3x3x3"] | None = None,
    intensity_difference_sigma: float | None = 1.0,
    patch_similarity_sigma: float | None = 1.0,
    scale_levels: str | None = "32x16x8x2x1",
    interpolation: typing.Literal["Linear", "NearestNeighbor", "Gaussian", "BSpline", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
) -> NonLocalSuperResolutionParameters:
    """
    Build parameters.
    
    Args:
        input_image: A low-resolution input image to be superresoluted.
        output: The output consists of the noise corrected version of the input\
            image. Optionally, one can also output the estimated noise image.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        interpolated_image: An interpolated version of the low-resolution image\
            (such as B-spline). Specify either this option or a high-resolution\
            multi-modal counterpart (cf the -k option).
        reference_image: A high-resolution reference multi-modal image. Assumed\
            to be in the same space as the low-resolution input image. Specify\
            either this option or an interpolated version (cf the -j option).
        patch_radius: Patch radius. Default = 1x1x1.
        search_radius: Search radius. Default = 3x3x3.
        intensity_difference_sigma: Intensity difference sigma. Default = 1.0.
        patch_similarity_sigma: Patch similarity sigma. Default = 1.0.
        scale_levels: Scale levels. Default = 32x16x8x2x1.
        interpolation: Several interpolation options are available in ITK.
        verbose: Verbose output.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "NonLocalSuperResolution",
        "input_image": input_image,
        "output": output,
    }
    if image_dimensionality is not None:
        params["image_dimensionality"] = image_dimensionality
    if interpolated_image is not None:
        params["interpolated_image"] = interpolated_image
    if reference_image is not None:
        params["reference_image"] = reference_image
    if patch_radius is not None:
        params["patch_radius"] = patch_radius
    if search_radius is not None:
        params["search_radius"] = search_radius
    if intensity_difference_sigma is not None:
        params["intensity_difference_sigma"] = intensity_difference_sigma
    if patch_similarity_sigma is not None:
        params["patch_similarity_sigma"] = patch_similarity_sigma
    if scale_levels is not None:
        params["scale_levels"] = scale_levels
    if interpolation is not None:
        params["interpolation"] = interpolation
    if verbose is not None:
        params["verbose"] = verbose
    return params


def non_local_super_resolution_cargs(
    params: NonLocalSuperResolutionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("NonLocalSuperResolution")
    if params.get("image_dimensionality") is not None:
        cargs.extend([
            "-d",
            str(params.get("image_dimensionality"))
        ])
    cargs.extend([
        "-i",
        execution.input_file(params.get("input_image"))
    ])
    if params.get("interpolated_image") is not None:
        cargs.extend([
            "-j",
            execution.input_file(params.get("interpolated_image"))
        ])
    if params.get("reference_image") is not None:
        cargs.extend([
            "-k",
            execution.input_file(params.get("reference_image"))
        ])
    if params.get("patch_radius") is not None:
        cargs.extend([
            "-p",
            params.get("patch_radius")
        ])
    if params.get("search_radius") is not None:
        cargs.extend([
            "-r",
            params.get("search_radius")
        ])
    if params.get("intensity_difference_sigma") is not None:
        cargs.extend([
            "-g",
            str(params.get("intensity_difference_sigma"))
        ])
    if params.get("patch_similarity_sigma") is not None:
        cargs.extend([
            "-t",
            str(params.get("patch_similarity_sigma"))
        ])
    if params.get("scale_levels") is not None:
        cargs.extend([
            "-s",
            params.get("scale_levels")
        ])
    if params.get("interpolation") is not None:
        cargs.extend([
            "-n",
            params.get("interpolation")
        ])
    cargs.extend([
        "-o",
        params.get("output")
    ])
    if params.get("verbose") is not None:
        cargs.extend([
            "-v",
            str(params.get("verbose"))
        ])
    return cargs


def non_local_super_resolution_outputs(
    params: NonLocalSuperResolutionParameters,
    execution: Execution,
) -> NonLocalSuperResolutionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = NonLocalSuperResolutionOutputs(
        root=execution.output_file("."),
        superresoluted_output=execution.output_file(params.get("output")),
    )
    return ret


def non_local_super_resolution_execute(
    params: NonLocalSuperResolutionParameters,
    execution: Execution,
) -> NonLocalSuperResolutionOutputs:
    """
    Non-local super resolution described in the papers by JV Manjon et al., focusing
    on MRI superresolution using self-similarity and image priors.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `NonLocalSuperResolutionOutputs`).
    """
    params = execution.params(params)
    cargs = non_local_super_resolution_cargs(params, execution)
    ret = non_local_super_resolution_outputs(params, execution)
    execution.run(cargs)
    return ret


def non_local_super_resolution(
    input_image: InputPathType,
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    interpolated_image: InputPathType | None = None,
    reference_image: InputPathType | None = None,
    patch_radius: typing.Literal["1", "1x1x1"] | None = None,
    search_radius: typing.Literal["3", "3x3x3"] | None = None,
    intensity_difference_sigma: float | None = 1.0,
    patch_similarity_sigma: float | None = 1.0,
    scale_levels: str | None = "32x16x8x2x1",
    interpolation: typing.Literal["Linear", "NearestNeighbor", "Gaussian", "BSpline", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> NonLocalSuperResolutionOutputs:
    """
    Non-local super resolution described in the papers by JV Manjon et al., focusing
    on MRI superresolution using self-similarity and image priors.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: A low-resolution input image to be superresoluted.
        output: The output consists of the noise corrected version of the input\
            image. Optionally, one can also output the estimated noise image.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        interpolated_image: An interpolated version of the low-resolution image\
            (such as B-spline). Specify either this option or a high-resolution\
            multi-modal counterpart (cf the -k option).
        reference_image: A high-resolution reference multi-modal image. Assumed\
            to be in the same space as the low-resolution input image. Specify\
            either this option or an interpolated version (cf the -j option).
        patch_radius: Patch radius. Default = 1x1x1.
        search_radius: Search radius. Default = 3x3x3.
        intensity_difference_sigma: Intensity difference sigma. Default = 1.0.
        patch_similarity_sigma: Patch similarity sigma. Default = 1.0.
        scale_levels: Scale levels. Default = 32x16x8x2x1.
        interpolation: Several interpolation options are available in ITK.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NonLocalSuperResolutionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NON_LOCAL_SUPER_RESOLUTION_METADATA)
    params = non_local_super_resolution_params(
        image_dimensionality=image_dimensionality,
        input_image=input_image,
        interpolated_image=interpolated_image,
        reference_image=reference_image,
        patch_radius=patch_radius,
        search_radius=search_radius,
        intensity_difference_sigma=intensity_difference_sigma,
        patch_similarity_sigma=patch_similarity_sigma,
        scale_levels=scale_levels,
        interpolation=interpolation,
        output=output,
        verbose=verbose,
    )
    return non_local_super_resolution_execute(params, execution)


__all__ = [
    "NON_LOCAL_SUPER_RESOLUTION_METADATA",
    "NonLocalSuperResolutionOutputs",
    "NonLocalSuperResolutionParameters",
    "non_local_super_resolution",
    "non_local_super_resolution_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CREATE_DTICOHORT_METADATA = Metadata(
    id="b6d3b7b7d3095a9db5e406c42360be21bbfd0ce5.boutiques",
    name="CreateDTICohort",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


CreateDticohortParameters = typing.TypedDict('CreateDticohortParameters', {
    "__STYX_TYPE__": typing.Literal["CreateDTICohort"],
    "image_dimensionality": typing.NotRequired[typing.Literal[2, 3] | None],
    "dti_atlas": InputPathType,
    "label_mask_image": typing.NotRequired[str | None],
    "noise_sigma": typing.NotRequired[float | None],
    "pathology": typing.NotRequired[str | None],
    "dwi_parameters": str,
    "registered_population": typing.NotRequired[InputPathType | None],
    "output": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "CreateDTICohort": create_dticohort_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "CreateDTICohort": create_dticohort_outputs,
    }.get(t)


class CreateDticohortOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_dticohort(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_directory: OutputPathType
    """The directory where the output data will be stored."""
    filename_series: OutputPathType
    """Root name for the series of output files."""


def create_dticohort_params(
    dti_atlas: InputPathType,
    dwi_parameters: str,
    output: str,
    image_dimensionality: typing.Literal[2, 3] | None = None,
    label_mask_image: str | None = None,
    noise_sigma: float | None = None,
    pathology: str | None = None,
    registered_population: InputPathType | None = None,
) -> CreateDticohortParameters:
    """
    Build parameters.
    
    Args:
        dti_atlas: A diffusion tensor atlas image is required input for\
            creating the cohort.
        dwi_parameters: This option specifies the parameters of the output\
            diffusion-weighted images, including the directions and b-values.\
            Directions can be specified using a direction file or scheme file.
        output: The output consists of a set of diffusion-weighted images for\
            each subject. Control and experimental subject numbers can be\
            specified.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        label_mask_image: A mask image can be specified which determines the\
            region(s) to which the simulated pathology operations are applied. If\
            no mask is specified one is created by thresholding the atlas FA map at\
            0.2 unless a lower threshold is specified.
        noise_sigma: This parameter characterizes the Rician noise in the\
            original DWI images. Default value is 18.
        pathology: The user can specify the simulated pathology in a given area\
            using a label mask. Pathology is simulated by changing the eigenvalues.\
            One can specify the number of voxels affected in each region or the\
            proportion of voxels affected. Change is specified as a proportion of\
            the current eigenvalues.
        registered_population: To introduce inter-subject variability, a\
            registered DTI population to the DTI atlas is required. This is modeled\
            by PCA decomposition.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "CreateDTICohort",
        "dti_atlas": dti_atlas,
        "dwi_parameters": dwi_parameters,
        "output": output,
    }
    if image_dimensionality is not None:
        params["image_dimensionality"] = image_dimensionality
    if label_mask_image is not None:
        params["label_mask_image"] = label_mask_image
    if noise_sigma is not None:
        params["noise_sigma"] = noise_sigma
    if pathology is not None:
        params["pathology"] = pathology
    if registered_population is not None:
        params["registered_population"] = registered_population
    return params


def create_dticohort_cargs(
    params: CreateDticohortParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("CreateDTICohort")
    if params.get("image_dimensionality") is not None:
        cargs.extend([
            "--image-dimensionality",
            str(params.get("image_dimensionality"))
        ])
    cargs.extend([
        "--dti-atlas",
        execution.input_file(params.get("dti_atlas"))
    ])
    if params.get("label_mask_image") is not None:
        cargs.extend([
            "--label-mask-image",
            params.get("label_mask_image")
        ])
    if params.get("noise_sigma") is not None:
        cargs.extend([
            "--noise-sigma",
            str(params.get("noise_sigma"))
        ])
    if params.get("pathology") is not None:
        cargs.extend([
            "--pathology",
            params.get("pathology")
        ])
    cargs.extend([
        "--dwi-parameters",
        params.get("dwi_parameters")
    ])
    if params.get("registered_population") is not None:
        cargs.extend([
            "--registered-population",
            execution.input_file(params.get("registered_population"))
        ])
    cargs.extend([
        "--output",
        params.get("output")
    ])
    return cargs


def create_dticohort_outputs(
    params: CreateDticohortParameters,
    execution: Execution,
) -> CreateDticohortOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CreateDticohortOutputs(
        root=execution.output_file("."),
        output_directory=execution.output_file("[OUTPUT_DIRECTORY]"),
        filename_series=execution.output_file("[OUTPUT_DIRECTORY]/[FILENAME_SERIES_ROOT_NAME]_*.nii"),
    )
    return ret


def create_dticohort_execute(
    params: CreateDticohortParameters,
    execution: Execution,
) -> CreateDticohortOutputs:
    """
    CreateDTICohort implements the work of Van Hecke et al. to create simulated DTI
    data sets. The only difference is that all registrations (both for the input
    population and for the output population) are assumed to take place outside of
    this program.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `CreateDticohortOutputs`).
    """
    params = execution.params(params)
    cargs = create_dticohort_cargs(params, execution)
    ret = create_dticohort_outputs(params, execution)
    execution.run(cargs)
    return ret


def create_dticohort(
    dti_atlas: InputPathType,
    dwi_parameters: str,
    output: str,
    image_dimensionality: typing.Literal[2, 3] | None = None,
    label_mask_image: str | None = None,
    noise_sigma: float | None = None,
    pathology: str | None = None,
    registered_population: InputPathType | None = None,
    runner: Runner | None = None,
) -> CreateDticohortOutputs:
    """
    CreateDTICohort implements the work of Van Hecke et al. to create simulated DTI
    data sets. The only difference is that all registrations (both for the input
    population and for the output population) are assumed to take place outside of
    this program.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dti_atlas: A diffusion tensor atlas image is required input for\
            creating the cohort.
        dwi_parameters: This option specifies the parameters of the output\
            diffusion-weighted images, including the directions and b-values.\
            Directions can be specified using a direction file or scheme file.
        output: The output consists of a set of diffusion-weighted images for\
            each subject. Control and experimental subject numbers can be\
            specified.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        label_mask_image: A mask image can be specified which determines the\
            region(s) to which the simulated pathology operations are applied. If\
            no mask is specified one is created by thresholding the atlas FA map at\
            0.2 unless a lower threshold is specified.
        noise_sigma: This parameter characterizes the Rician noise in the\
            original DWI images. Default value is 18.
        pathology: The user can specify the simulated pathology in a given area\
            using a label mask. Pathology is simulated by changing the eigenvalues.\
            One can specify the number of voxels affected in each region or the\
            proportion of voxels affected. Change is specified as a proportion of\
            the current eigenvalues.
        registered_population: To introduce inter-subject variability, a\
            registered DTI population to the DTI atlas is required. This is modeled\
            by PCA decomposition.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateDticohortOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_DTICOHORT_METADATA)
    params = create_dticohort_params(
        image_dimensionality=image_dimensionality,
        dti_atlas=dti_atlas,
        label_mask_image=label_mask_image,
        noise_sigma=noise_sigma,
        pathology=pathology,
        dwi_parameters=dwi_parameters,
        registered_population=registered_population,
        output=output,
    )
    return create_dticohort_execute(params, execution)


__all__ = [
    "CREATE_DTICOHORT_METADATA",
    "CreateDticohortOutputs",
    "CreateDticohortParameters",
    "create_dticohort",
    "create_dticohort_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_NEUROIMAGING_BATTERY_METADATA = Metadata(
    id="8d5f7d9ec665c8a4728e1d76b9ae72be2a9a3489.boutiques",
    name="antsNeuroimagingBattery",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsNeuroimagingBatteryParameters = typing.TypedDict('AntsNeuroimagingBatteryParameters', {
    "__STYX_TYPE__": typing.Literal["antsNeuroimagingBattery"],
    "input_directory": str,
    "output_directory": str,
    "output_name": str,
    "anatomical_image": InputPathType,
    "anatomical_mask": InputPathType,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsNeuroimagingBattery": ants_neuroimaging_battery_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsNeuroimagingBattery": ants_neuroimaging_battery_outputs,
    }.get(t)


class AntsNeuroimagingBatteryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_neuroimaging_battery(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform: OutputPathType
    """Output transform files."""


def ants_neuroimaging_battery_params(
    input_directory: str,
    output_directory: str,
    output_name: str,
    anatomical_image: InputPathType,
    anatomical_mask: InputPathType,
) -> AntsNeuroimagingBatteryParameters:
    """
    Build parameters.
    
    Args:
        input_directory: Directory where to look for modality images.
        output_directory: Directory where output goes (where\
            antsCorticalThickness output lives).
        output_name: File prefix for outputs.
        anatomical_image: Reference subject image (usually T1).
        anatomical_mask: Mask of anatomical image, should contain cerebrum,\
            cerebellum, and brainstem.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsNeuroimagingBattery",
        "input_directory": input_directory,
        "output_directory": output_directory,
        "output_name": output_name,
        "anatomical_image": anatomical_image,
        "anatomical_mask": anatomical_mask,
    }
    return params


def ants_neuroimaging_battery_cargs(
    params: AntsNeuroimagingBatteryParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsNeuroimagingBattery.pl")
    cargs.extend([
        "--input-directory",
        params.get("input_directory")
    ])
    cargs.extend([
        "--output-directory",
        params.get("output_directory")
    ])
    cargs.extend([
        "--output-name",
        params.get("output_name")
    ])
    cargs.extend([
        "--anatomical",
        execution.input_file(params.get("anatomical_image"))
    ])
    cargs.extend([
        "--anatomical-mask",
        execution.input_file(params.get("anatomical_mask"))
    ])
    cargs.append("[OPTIONAL_INPUTS]")
    return cargs


def ants_neuroimaging_battery_outputs(
    params: AntsNeuroimagingBatteryParameters,
    execution: Execution,
) -> AntsNeuroimagingBatteryOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsNeuroimagingBatteryOutputs(
        root=execution.output_file("."),
        output_transform=execution.output_file(params.get("output_directory") + "/" + params.get("output_name") + ".*"),
    )
    return ret


def ants_neuroimaging_battery_execute(
    params: AntsNeuroimagingBatteryParameters,
    execution: Execution,
) -> AntsNeuroimagingBatteryOutputs:
    """
    Align MR modalities to a common within-subject (and optional template) space.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsNeuroimagingBatteryOutputs`).
    """
    params = execution.params(params)
    cargs = ants_neuroimaging_battery_cargs(params, execution)
    ret = ants_neuroimaging_battery_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_neuroimaging_battery(
    input_directory: str,
    output_directory: str,
    output_name: str,
    anatomical_image: InputPathType,
    anatomical_mask: InputPathType,
    runner: Runner | None = None,
) -> AntsNeuroimagingBatteryOutputs:
    """
    Align MR modalities to a common within-subject (and optional template) space.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_directory: Directory where to look for modality images.
        output_directory: Directory where output goes (where\
            antsCorticalThickness output lives).
        output_name: File prefix for outputs.
        anatomical_image: Reference subject image (usually T1).
        anatomical_mask: Mask of anatomical image, should contain cerebrum,\
            cerebellum, and brainstem.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsNeuroimagingBatteryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_NEUROIMAGING_BATTERY_METADATA)
    params = ants_neuroimaging_battery_params(
        input_directory=input_directory,
        output_directory=output_directory,
        output_name=output_name,
        anatomical_image=anatomical_image,
        anatomical_mask=anatomical_mask,
    )
    return ants_neuroimaging_battery_execute(params, execution)


__all__ = [
    "ANTS_NEUROIMAGING_BATTERY_METADATA",
    "AntsNeuroimagingBatteryOutputs",
    "AntsNeuroimagingBatteryParameters",
    "ants_neuroimaging_battery",
    "ants_neuroimaging_battery_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_JOINT_LABEL_FUSION_SH_METADATA = Metadata(
    id="247a29d0e6dd59cbbad0a89af0ca5b7e052f7e73.boutiques",
    name="antsJointLabelFusion.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsJointLabelFusionShParameters = typing.TypedDict('AntsJointLabelFusionShParameters', {
    "__STYX_TYPE__": typing.Literal["antsJointLabelFusion.sh"],
    "dimensionality": typing.NotRequired[typing.Literal[2, 3] | None],
    "output": typing.NotRequired[str | None],
    "atlas_image_mrf": typing.NotRequired[str | None],
    "atlas_segmentation_mrf": typing.NotRequired[str | None],
    "rigid_transform": typing.NotRequired[str | None],
    "similarity_metric": typing.NotRequired[str | None],
    "other_options": typing.NotRequired[str | None],
    "verbose": typing.NotRequired[typing.Literal[0, 1] | None],
    "target_image": str,
    "mask_image": str,
    "rigid_transform_additional_options": typing.NotRequired[str | None],
    "similarity_metric_additional_options": typing.NotRequired[str | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsJointLabelFusion.sh": ants_joint_label_fusion_sh_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsJointLabelFusion.sh": ants_joint_label_fusion_sh_outputs,
    }.get(t)


class AntsJointLabelFusionShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_joint_label_fusion_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType | None
    """Output segmented image."""


def ants_joint_label_fusion_sh_params(
    target_image: str,
    mask_image: str,
    dimensionality: typing.Literal[2, 3] | None = None,
    output: str | None = None,
    atlas_image_mrf: str | None = None,
    atlas_segmentation_mrf: str | None = None,
    rigid_transform: str | None = None,
    similarity_metric: str | None = None,
    other_options: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    rigid_transform_additional_options: str | None = None,
    similarity_metric_additional_options: str | None = None,
) -> AntsJointLabelFusionShParameters:
    """
    Build parameters.
    
    Args:
        target_image: Image to segment.
        mask_image: Mask image.
        dimensionality: Image dimensionality (2 or 3).
        output: Root directory for the output segmentation.
        atlas_image_mrf: Atlas image(s) to be used for MRF initialization.
        atlas_segmentation_mrf: Atlas segmentation(s) to be used for MRF\
            initialization.
        rigid_transform: Rigid transform initialization.
        similarity_metric: Metric used for calculating similarity.
        other_options: Additional options for label fusion.
        verbose: Verbose output.
        rigid_transform_additional_options: Additional options for rigid\
            transform.
        similarity_metric_additional_options: Additional options for similarity\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsJointLabelFusion.sh",
        "target_image": target_image,
        "mask_image": mask_image,
    }
    if dimensionality is not None:
        params["dimensionality"] = dimensionality
    if output is not None:
        params["output"] = output
    if atlas_image_mrf is not None:
        params["atlas_image_mrf"] = atlas_image_mrf
    if atlas_segmentation_mrf is not None:
        params["atlas_segmentation_mrf"] = atlas_segmentation_mrf
    if rigid_transform is not None:
        params["rigid_transform"] = rigid_transform
    if similarity_metric is not None:
        params["similarity_metric"] = similarity_metric
    if other_options is not None:
        params["other_options"] = other_options
    if verbose is not None:
        params["verbose"] = verbose
    if rigid_transform_additional_options is not None:
        params["rigid_transform_additional_options"] = rigid_transform_additional_options
    if similarity_metric_additional_options is not None:
        params["similarity_metric_additional_options"] = similarity_metric_additional_options
    return params


def ants_joint_label_fusion_sh_cargs(
    params: AntsJointLabelFusionShParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsJointLabelFusion.sh")
    if params.get("dimensionality") is not None:
        cargs.extend([
            "-d",
            str(params.get("dimensionality"))
        ])
    if params.get("output") is not None:
        cargs.extend([
            "-o",
            params.get("output")
        ])
    if params.get("atlas_image_mrf") is not None:
        cargs.extend([
            "-a",
            params.get("atlas_image_mrf")
        ])
    if params.get("atlas_segmentation_mrf") is not None:
        cargs.extend([
            "-l",
            params.get("atlas_segmentation_mrf")
        ])
    if params.get("rigid_transform") is not None:
        cargs.extend([
            "-g",
            params.get("rigid_transform")
        ])
    if params.get("similarity_metric") is not None:
        cargs.extend([
            "-s",
            params.get("similarity_metric")
        ])
    if params.get("other_options") is not None:
        cargs.extend([
            "-k",
            params.get("other_options")
        ])
    if params.get("verbose") is not None:
        cargs.extend([
            "-v",
            str(params.get("verbose"))
        ])
    cargs.extend([
        "-i",
        params.get("target_image")
    ])
    cargs.extend([
        "-m",
        params.get("mask_image")
    ])
    if params.get("rigid_transform_additional_options") is not None:
        cargs.extend([
            "-g",
            params.get("rigid_transform_additional_options")
        ])
    if params.get("similarity_metric_additional_options") is not None:
        cargs.extend([
            "-x",
            params.get("similarity_metric_additional_options")
        ])
    return cargs


def ants_joint_label_fusion_sh_outputs(
    params: AntsJointLabelFusionShParameters,
    execution: Execution,
) -> AntsJointLabelFusionShOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsJointLabelFusionShOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(params.get("output") + ".nii.gz") if (params.get("output") is not None) else None,
    )
    return ret


def ants_joint_label_fusion_sh_execute(
    params: AntsJointLabelFusionShParameters,
    execution: Execution,
) -> AntsJointLabelFusionShOutputs:
    """
    The antsJointLabelFusion script is used for performing label fusion using
    multiple atlases to improve segmentation accuracy.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsJointLabelFusionShOutputs`).
    """
    params = execution.params(params)
    cargs = ants_joint_label_fusion_sh_cargs(params, execution)
    ret = ants_joint_label_fusion_sh_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_joint_label_fusion_sh(
    target_image: str,
    mask_image: str,
    dimensionality: typing.Literal[2, 3] | None = None,
    output: str | None = None,
    atlas_image_mrf: str | None = None,
    atlas_segmentation_mrf: str | None = None,
    rigid_transform: str | None = None,
    similarity_metric: str | None = None,
    other_options: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    rigid_transform_additional_options: str | None = None,
    similarity_metric_additional_options: str | None = None,
    runner: Runner | None = None,
) -> AntsJointLabelFusionShOutputs:
    """
    The antsJointLabelFusion script is used for performing label fusion using
    multiple atlases to improve segmentation accuracy.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        target_image: Image to segment.
        mask_image: Mask image.
        dimensionality: Image dimensionality (2 or 3).
        output: Root directory for the output segmentation.
        atlas_image_mrf: Atlas image(s) to be used for MRF initialization.
        atlas_segmentation_mrf: Atlas segmentation(s) to be used for MRF\
            initialization.
        rigid_transform: Rigid transform initialization.
        similarity_metric: Metric used for calculating similarity.
        other_options: Additional options for label fusion.
        verbose: Verbose output.
        rigid_transform_additional_options: Additional options for rigid\
            transform.
        similarity_metric_additional_options: Additional options for similarity\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsJointLabelFusionShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_JOINT_LABEL_FUSION_SH_METADATA)
    params = ants_joint_label_fusion_sh_params(
        dimensionality=dimensionality,
        output=output,
        atlas_image_mrf=atlas_image_mrf,
        atlas_segmentation_mrf=atlas_segmentation_mrf,
        rigid_transform=rigid_transform,
        similarity_metric=similarity_metric,
        other_options=other_options,
        verbose=verbose,
        target_image=target_image,
        mask_image=mask_image,
        rigid_transform_additional_options=rigid_transform_additional_options,
        similarity_metric_additional_options=similarity_metric_additional_options,
    )
    return ants_joint_label_fusion_sh_execute(params, execution)


__all__ = [
    "ANTS_JOINT_LABEL_FUSION_SH_METADATA",
    "AntsJointLabelFusionShOutputs",
    "AntsJointLabelFusionShParameters",
    "ants_joint_label_fusion_sh",
    "ants_joint_label_fusion_sh_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANTS_MOTION_CORR_STATS_METADATA = Metadata(
    id="ae93cc3983b8309bee22c105a3b82c9e97354cf5.boutiques",
    name="antsMotionCorrStats",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AntsMotionCorrStatsParameters = typing.TypedDict('AntsMotionCorrStatsParameters', {
    "__STYX_TYPE__": typing.Literal["antsMotionCorrStats"],
    "mask": InputPathType,
    "moco_params": InputPathType,
    "output": str,
    "transform_index": typing.NotRequired[int | None],
    "framewise": typing.NotRequired[typing.Literal[0, 1] | None],
    "spatial_map": bool,
    "timeseries_displacement": bool,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "antsMotionCorrStats": ants_motion_corr_stats_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "antsMotionCorrStats": ants_motion_corr_stats_outputs,
    }.get(t)


class AntsMotionCorrStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_motion_corr_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_csv: OutputPathType
    """The corrected motion parameters.csv file."""


def ants_motion_corr_stats_params(
    mask: InputPathType,
    moco_params: InputPathType,
    output: str,
    transform_index: int | None = None,
    framewise: typing.Literal[0, 1] | None = None,
    spatial_map: bool = False,
    timeseries_displacement: bool = False,
) -> AntsMotionCorrStatsParameters:
    """
    Build parameters.
    
    Args:
        mask: Mask image - compute displacements within mask.
        moco_params: Motion correction parameters from antsMotionCorr.
        output: Specify the output file.
        transform_index: Specify the index for a 3D transform to output.
        framewise: Do framewise summary stats.
        spatial_map: Output image of displacement magnitude.
        timeseries_displacement: Output 4d time-series image of displacement\
            magnitude.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "antsMotionCorrStats",
        "mask": mask,
        "moco_params": moco_params,
        "output": output,
        "spatial_map": spatial_map,
        "timeseries_displacement": timeseries_displacement,
    }
    if transform_index is not None:
        params["transform_index"] = transform_index
    if framewise is not None:
        params["framewise"] = framewise
    return params


def ants_motion_corr_stats_cargs(
    params: AntsMotionCorrStatsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("antsMotionCorrStats")
    cargs.extend([
        "-x",
        execution.input_file(params.get("mask"))
    ])
    cargs.extend([
        "-m",
        execution.input_file(params.get("moco_params"))
    ])
    cargs.extend([
        "-o",
        params.get("output")
    ])
    if params.get("transform_index") is not None:
        cargs.extend([
            "-t",
            str(params.get("transform_index"))
        ])
    if params.get("framewise") is not None:
        cargs.extend([
            "-f",
            str(params.get("framewise"))
        ])
    if params.get("spatial_map"):
        cargs.append("-s")
    if params.get("timeseries_displacement"):
        cargs.append("-d")
    return cargs


def ants_motion_corr_stats_outputs(
    params: AntsMotionCorrStatsParameters,
    execution: Execution,
) -> AntsMotionCorrStatsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AntsMotionCorrStatsOutputs(
        root=execution.output_file("."),
        corrected_csv=execution.output_file(params.get("output")),
    )
    return ret


def ants_motion_corr_stats_execute(
    params: AntsMotionCorrStatsParameters,
    execution: Execution,
) -> AntsMotionCorrStatsOutputs:
    """
    Create summary measures of the parameters that are output by antsMotionCorr.
    Currently only works for linear transforms. Outputs the mean and max
    displacements for the voxels within a provided mask, at each time point. By
    default the displacements are relative to the reference space, but the framewise
    option may be used to provide displacements between consecutive time points.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrStatsOutputs`).
    """
    params = execution.params(params)
    cargs = ants_motion_corr_stats_cargs(params, execution)
    ret = ants_motion_corr_stats_outputs(params, execution)
    execution.run(cargs)
    return ret


def ants_motion_corr_stats(
    mask: InputPathType,
    moco_params: InputPathType,
    output: str,
    transform_index: int | None = None,
    framewise: typing.Literal[0, 1] | None = None,
    spatial_map: bool = False,
    timeseries_displacement: bool = False,
    runner: Runner | None = None,
) -> AntsMotionCorrStatsOutputs:
    """
    Create summary measures of the parameters that are output by antsMotionCorr.
    Currently only works for linear transforms. Outputs the mean and max
    displacements for the voxels within a provided mask, at each time point. By
    default the displacements are relative to the reference space, but the framewise
    option may be used to provide displacements between consecutive time points.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        mask: Mask image - compute displacements within mask.
        moco_params: Motion correction parameters from antsMotionCorr.
        output: Specify the output file.
        transform_index: Specify the index for a 3D transform to output.
        framewise: Do framewise summary stats.
        spatial_map: Output image of displacement magnitude.
        timeseries_displacement: Output 4d time-series image of displacement\
            magnitude.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MOTION_CORR_STATS_METADATA)
    params = ants_motion_corr_stats_params(
        mask=mask,
        moco_params=moco_params,
        output=output,
        transform_index=transform_index,
        framewise=framewise,
        spatial_map=spatial_map,
        timeseries_displacement=timeseries_displacement,
    )
    return ants_motion_corr_stats_execute(params, execution)


__all__ = [
    "ANTS_MOTION_CORR_STATS_METADATA",
    "AntsMotionCorrStatsOutputs",
    "AntsMotionCorrStatsParameters",
    "ants_motion_corr_stats",
    "ants_motion_corr_stats_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

TILE_IMAGES_METADATA = Metadata(
    id="d25b8eb520a9f772e1be8a0571d47dff47f48e49.boutiques",
    name="TileImages",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


TileImagesParameters = typing.TypedDict('TileImagesParameters', {
    "__STYX_TYPE__": typing.Literal["TileImages"],
    "image_dimension": int,
    "output_image": str,
    "layout": str,
    "input_images": list[InputPathType],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "TileImages": tile_images_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "TileImages": tile_images_outputs,
    }.get(t)


class TileImagesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tile_images(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tiled_image: OutputPathType
    """The final tiled output image."""


def tile_images_params(
    image_dimension: int,
    output_image: str,
    layout: str,
    input_images: list[InputPathType],
) -> TileImagesParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: Dimensionality of the output image.
        output_image: The path for the output tiled image.
        layout: Defines the structure of the tiled output image. The layout\
            dictates the number and arrangement of input images in the output\
            image.
        input_images: Input images to be tiled into the output image. The\
            number of input images should match the layout specification.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "TileImages",
        "image_dimension": image_dimension,
        "output_image": output_image,
        "layout": layout,
        "input_images": input_images,
    }
    return params


def tile_images_cargs(
    params: TileImagesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("TileImages")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(params.get("output_image"))
    cargs.append(params.get("layout"))
    cargs.extend([execution.input_file(f) for f in params.get("input_images")])
    return cargs


def tile_images_outputs(
    params: TileImagesParameters,
    execution: Execution,
) -> TileImagesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = TileImagesOutputs(
        root=execution.output_file("."),
        tiled_image=execution.output_file(params.get("output_image")),
    )
    return ret


def tile_images_execute(
    params: TileImagesParameters,
    execution: Execution,
) -> TileImagesOutputs:
    """
    TileImages allows assembling images into a multi-dimensional array, producing a
    single output image. The input images must have a dimension less than or equal
    to the specified output image dimension.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `TileImagesOutputs`).
    """
    params = execution.params(params)
    cargs = tile_images_cargs(params, execution)
    ret = tile_images_outputs(params, execution)
    execution.run(cargs)
    return ret


def tile_images(
    image_dimension: int,
    output_image: str,
    layout: str,
    input_images: list[InputPathType],
    runner: Runner | None = None,
) -> TileImagesOutputs:
    """
    TileImages allows assembling images into a multi-dimensional array, producing a
    single output image. The input images must have a dimension less than or equal
    to the specified output image dimension.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the output image.
        output_image: The path for the output tiled image.
        layout: Defines the structure of the tiled output image. The layout\
            dictates the number and arrangement of input images in the output\
            image.
        input_images: Input images to be tiled into the output image. The\
            number of input images should match the layout specification.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TileImagesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TILE_IMAGES_METADATA)
    params = tile_images_params(
        image_dimension=image_dimension,
        output_image=output_image,
        layout=layout,
        input_images=input_images,
    )
    return tile_images_execute(params, execution)


__all__ = [
    "TILE_IMAGES_METADATA",
    "TileImagesOutputs",
    "TileImagesParameters",
    "tile_images",
    "tile_images_params",
]
